<img src="/ti/docs/images/tf-small.png" align="left"/>

# Text-Info

[![Project Status: Active – The project has reached a stable, usable state and is being actively developed.](https://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active)

All about Text-Info is in the
[docs](https://annotation.github.io/text-info/ti).

Validate TEI corpora, make inventories of significant information,
distil page sequences and combine it with scan information,
generate IIIF manifests.

At the moment, I'm testing the code on the Israels corpus, in this
[notebook](https://github.com/HuygensING/israels/blob/main/programs/inventory.ipynb)
